@@ -1,6 +1,6 @@
 //
 //	aegis - project change supervisor
-//	Copyright (C) 2002-2004 Peter Miller;
+//	Copyright (C) 2002-2005 Peter Miller;
 //	All rights reserved.
 //
 //	This program is free software; you can redistribute it and/or modify
@@ -20,9 +20,9 @@
 // MANIFEST: functions to manipulate unknowns
 //
 
-#include <command/private.h>
-#include <command/unknown.h>
-#include <complete/nil.h>
+#include <aecomplete/command/private.h>
+#include <aecomplete/command/unknown.h>
+#include <aecomplete/complete/nil.h>
 
 
 static void
