@@ -1,6 +1,6 @@
 //
 //	aegis - project change supervisor
-//	Copyright (C) 2002-2004 Peter Miller;
+//	Copyright (C) 2002-2005 Peter Miller;
 //	All rights reserved.
 //
 //	This program is free software; you can redistribute it and/or modify
@@ -20,8 +20,8 @@
 // MANIFEST: functions to manipulate privates
 //
 
-#include <complete/private.h>
-#include <mem.h>
+#include <aecomplete/complete/private.h>
+#include <common/mem.h>
 
 
 complete_ty *
