@@ -1,6 +1,6 @@
 //
 //	aegis - project change supervisor
-//	Copyright (C) 2002-2004 Peter Miller;
+//	Copyright (C) 2002-2005 Peter Miller;
 //	All rights reserved.
 //
 //	This program is free software; you can redistribute it and/or modify
@@ -20,10 +20,10 @@
 // MANIFEST: functions to manipulate integrators
 //
 
-#include <complete/user.h>
-#include <complete/user/integrator.h>
-#include <project.h>
-#include <project/history.h>
+#include <aecomplete/complete/user.h>
+#include <aecomplete/complete/user/integrator.h>
+#include <libaegis/project.h>
+#include <libaegis/project/history.h>
 
 
 static int
