@@ -1,6 +1,6 @@
 //
 //	aegis - project change supervisor
-//	Copyright (C) 2004 Peter Miller;
+//	Copyright (C) 2004, 2005 Peter Miller;
 //	All rights reserved.
 //
 //	This program is free software; you can redistribute it and/or modify
@@ -23,7 +23,7 @@
 #ifndef AECVSSERVER_FILE_INFO_H
 #define AECVSSERVER_FILE_INFO_H
 
-#include <main.h>
+#include <common/main.h>
 
 struct file_info_ty
 {
