@@ -1,6 +1,6 @@
 //
 //	aegis - project change supervisor
-//	Copyright (C) 2004 Peter Miller;
+//	Copyright (C) 2004-2006 Peter Miller;
 //	All rights reserved.
 //
 //	This program is free software; you can redistribute it and/or modify
@@ -30,12 +30,23 @@
 // Root required: no.
 //
 
-#include <request/init.h>
-#include <server.h>
+#include <aecvsserver/request/init.h>
+#include <aecvsserver/server.h>
 
 
-static void
-run(server_ty *sp, string_ty *arg)
+request_init::~request_init()
+{
+}
+
+
+request_init::request_init()
+{
+}
+
+
+void
+request_init::run_inner(server_ty *sp, string_ty *arg)
+    const
 {
     server_error
     (
@@ -45,9 +56,17 @@ run(server_ty *sp, string_ty *arg)
 }
 
 
-const request_ty request_init =
+const char *
+request_init::name()
+    const
 {
-    "int",
-    run,
-    1, // reset
-};
+    return "init";
+}
+
+
+bool
+request_init::reset()
+    const
+{
+    return true;
+}
