@@ -1,6 +1,6 @@
 //
 //	aegis - project change supervisor
-//	Copyright (C) 2004, 2005 Peter Miller;
+//	Copyright (C) 2004-2006 Peter Miller;
 //	All rights reserved.
 //
 //	This program is free software; you can redistribute it and/or modify
@@ -20,26 +20,26 @@
 // MANIFEST: implementation of the missing class
 //
 
-#include <ael/column_width.h>
-#include <arglex3.h>
-#include <arglex/project.h>
-#include <change/functor/invent_build.h>
-#include <col.h>
-#include <error.h>
-#include <help.h>
-#include <input/file.h>
-#include <missing.h>
-#include <nstring/list.h>
-#include <os.h>
-#include <output.h>
-#include <project.h>
-#include <project/invento_walk.h>
-#include <replay/line.h>
-#include <symtab/template.h>
-#include <trace.h>
-#include <url.h>
-#include <usage.h>
-#include <user.h>
+#include <libaegis/ael/column_width.h>
+#include <aedist/arglex3.h>
+#include <libaegis/arglex/project.h>
+#include <aedist/change/functor/invent_build.h>
+#include <libaegis/col.h>
+#include <common/error.h>
+#include <libaegis/help.h>
+#include <libaegis/input/file.h>
+#include <aedist/missing.h>
+#include <common/nstring/list.h>
+#include <libaegis/os.h>
+#include <libaegis/output.h>
+#include <libaegis/project.h>
+#include <libaegis/project/invento_walk.h>
+#include <aedist/replay/line.h>
+#include <common/symtab/template.h>
+#include <common/trace.h>
+#include <libaegis/url.h>
+#include <aeannotate/usage.h>
+#include <libaegis/user.h>
 
 
 void
@@ -152,7 +152,7 @@ missing_main(void)
     if (!project_name)
         project_name = user_default_project();
     project_ty *pp = project_alloc(project_name);
-    project_bind_existing(pp);
+    pp->bind_existing();
 
     symtab<change_ty> local_inventory;
     bool include_branches = true;
@@ -173,7 +173,7 @@ missing_main(void)
     {
 	smart_url.set_path_if_empty
 	(
-	    nstring::format("/cgi-bin/aeget/%s", project_name_get(pp)->str_text)
+	    nstring::format("cgi-bin/aeget/%s", project_name_get(pp)->str_text)
 	);
 	smart_url.set_query_if_empty("inventory");
 	ifn = smart_url.reassemble();
@@ -184,7 +184,7 @@ missing_main(void)
     // Open the file (or URL) containing the inventory.
     //
     os_become_orig();
-    input_ty *ifp = input_file_open(ifn.get_ref());
+    input ifp = input_file_open(ifn.get_ref());
     os_become_undo();
 
     //
