@@ -1,29 +1,29 @@
-/*
- *	aegis - project change supervisor
- *	Copyright (C) 1997, 2002, 2003, 2005 Peter Miller;
- *	All rights reserved.
- *
- *	This program is free software; you can redistribute it and/or modify
- *	it under the terms of the GNU General Public License as published by
- *	the Free Software Foundation; either version 2 of the License, or
- *	(at your option) any later version.
- *
- *	This program is distributed in the hope that it will be useful,
- *	but WITHOUT ANY WARRANTY; without even the implied warranty of
- *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *	GNU General Public License for more details.
- *
- *	You should have received a copy of the GNU General Public License
- *	along with this program; if not, write to the Free Software
- *	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
- *
- * MANIFEST: interface definition for aefind/lex.c
- */
+//
+//	aegis - project change supervisor
+//	Copyright (C) 1997, 2002, 2003, 2005, 2006 Peter Miller;
+//	All rights reserved.
+//
+//	This program is free software; you can redistribute it and/or modify
+//	it under the terms of the GNU General Public License as published by
+//	the Free Software Foundation; either version 2 of the License, or
+//	(at your option) any later version.
+//
+//	This program is distributed in the hope that it will be useful,
+//	but WITHOUT ANY WARRANTY; without even the implied warranty of
+//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+//	GNU General Public License for more details.
+//
+//	You should have received a copy of the GNU General Public License
+//	along with this program; if not, write to the Free Software
+//	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
+//
+// MANIFEST: interface definition for aefind/lex.c
+//
 
 #ifndef AEFIND_LEX_H
 #define AEFIND_LEX_H
 
-#include <arglex2.h>
+#include <libaegis/arglex2.h>
 
 enum
 {
@@ -80,7 +80,7 @@ int cmdline_lex(void);
 void cmdline_error(const char *);
 void usage(void);
 
-struct sub_context_ty; /* existence */
+struct sub_context_ty; // existence
 void cmdline_lex_error(struct sub_context_ty *, const char *);
 
-#endif /* AEFIND_LEX_H */
+#endif // AEFIND_LEX_H
