@@ -1,6 +1,6 @@
 //
 //	aegis - project change supervisor
-//	Copyright (C) 2003, 2004 Peter Miller;
+//	Copyright (C) 2003-2005 Peter Miller;
 //	All rights reserved.
 //
 //	This program is free software; you can redistribute it and/or modify
@@ -20,12 +20,12 @@
 // MANIFEST: functions to manipulate commands
 //
 
-#include <ac/errno.h>
-#include <ac/unistd.h>
+#include <common/ac/errno.h>
+#include <common/ac/unistd.h>
 
-#include <get/command.h>
-#include <os.h>
-#include <sub.h>
+#include <aeget/get/command.h>
+#include <libaegis/os.h>
+#include <libaegis/sub.h>
 
 
 void
