@@ -1,6 +1,6 @@
 //
 //	aegis - project change supervisor
-//	Copyright (C) 2003, 2004 Peter Miller;
+//	Copyright (C) 2003-2005 Peter Miller;
 //	All rights reserved.
 //
 //	This program is free software; you can redistribute it and/or modify
@@ -20,11 +20,11 @@
 // MANIFEST: functions to manipulate aedists
 //
 
-#include <get/command.h>
-#include <get/project/aedist.h>
-#include <libdir.h>
-#include <project.h>
-#include <str_list.h>
+#include <aeget/get/command.h>
+#include <aeget/get/project/aedist.h>
+#include <common/libdir.h>
+#include <libaegis/project.h>
+#include <common/str_list.h>
 
 
 void
