@@ -1,6 +1,6 @@
 //
 //	aegis - project change supervisor
-//	Copyright (C) 2003, 2004 Peter Miller;
+//	Copyright (C) 2003-2005 Peter Miller;
 //	All rights reserved.
 //
 //	This program is free software; you can redistribute it and/or modify
@@ -20,13 +20,13 @@
 // MANIFEST: functions to manipulate files
 //
 
-#include <ac/stdio.h> // HACK
+#include <common/ac/stdio.h> // HACK
 
-#include <change.h>
-#include <get/file.h>
-#include <get/project/file.h>
-#include <project.h>
-#include <str_list.h>
+#include <libaegis/change.h>
+#include <aeget/get/file.h>
+#include <aeget/get/project/file.h>
+#include <libaegis/project.h>
+#include <common/str_list.h>
 
 
 void
