@@ -1,6 +1,6 @@
 //
 //      aegis - project change supervisor
-//      Copyright (C) 2003, 2004 Peter Miller;
+//      Copyright (C) 2003-2005 Peter Miller;
 //      All rights reserved.
 //
 //      This program is free software; you can redistribute it and/or modify
@@ -23,7 +23,7 @@
 #ifndef AEGET_HTTP_H
 #define AEGET_HTTP_H
 
-#include <main.h>
+#include <common/main.h>
 
 class nstring; // forward
 struct change_ty; // forward
