@@ -20,80 +20,79 @@
 // MANIFEST: the operating system start-up point
 //
 
-#include <ac/stdio.h>
-#include <ac/stdlib.h>
-#include <ac/unistd.h>
-#include <ac/signal.h>
+#include <common/ac/stdio.h>
+#include <common/ac/stdlib.h>
+#include <common/ac/unistd.h>
+#include <common/ac/signal.h>
 
-#include <aeb.h>
-#include <aeca.h>
-#include <aecd.h>
-#include <aechown.h>
-#include <aeclean.h>
-#include <aeclone.h>
-#include <aecp.h>
-#include <aecpu.h>
-#include <aed.h>
-#include <aedb.h>
-#include <aedbu.h>
-#include <aede.h>
-#include <aedeu.h>
-#include <aedn.h>
-#include <aefa.h>
-#include <aeib.h>
-#include <aeibu.h>
-#include <aeif.h>
-#include <aeip.h>
-#include <ael.h>
-#include <aemt.h>
-#include <aemtu.h>
-#include <aemv.h>
-#include <aemvu.h>
-#include <aena.h>
-#include <aenbr.h>
-#include <aenbru.h>
-#include <aenc.h>
-#include <aencu.h>
-#include <aend.h>
-#include <aenf.h>
-#include <aenfu.h>
-#include <aeni.h>
-#include <aenpa.h>
-#include <aenpr.h>
-#include <aenrls.h>
-#include <aenrv.h>
-#include <aent.h>
-#include <aentu.h>
-#include <aepa.h>
-#include <aer.h>
-#include <aera.h>
-#include <aerb.h>
-#include <aerbu.h>
-#include <aerd.h>
-#include <aerf.h>
-#include <aeri.h>
-#include <aerm.h>
-#include <aermpr.h>
-#include <aermu.h>
-#include <aerp.h>
-#include <aerpa.h>
-#include <aerpu.h>
-#include <aerrv.h>
-#include <aet.h>
-#include <arglex2.h>
-#include <configured.h>
-#include <env.h>
-#include <help.h>
-#include <language.h>
-#include <log.h>
-#include <os.h>
-#include <progname.h>
-#include <quit.h>
-#include <r250.h>
-#include <rsrc_limits.h>
-#include <trace.h>
-#include <undo.h>
-#include <version.h>
+#include <aegis/aeb.h>
+#include <aegis/aeca.h>
+#include <aegis/aecd.h>
+#include <aegis/aechown.h>
+#include <aegis/aeclean.h>
+#include <aegis/aeclone.h>
+#include <aegis/aecp.h>
+#include <aegis/aecpu.h>
+#include <aegis/aed.h>
+#include <aegis/aedb.h>
+#include <aegis/aedbu.h>
+#include <aegis/aede.h>
+#include <aegis/aedeu.h>
+#include <aegis/aedn.h>
+#include <aegis/aefa.h>
+#include <aegis/aeib.h>
+#include <aegis/aeibu.h>
+#include <aegis/aeif.h>
+#include <aegis/aeip.h>
+#include <aegis/ael.h>
+#include <aegis/aemt.h>
+#include <aegis/aemtu.h>
+#include <aegis/aemv.h>
+#include <aegis/aemvu.h>
+#include <aegis/aena.h>
+#include <aegis/aenbr.h>
+#include <aegis/aenbru.h>
+#include <aegis/aenc.h>
+#include <aegis/aencu.h>
+#include <aegis/aend.h>
+#include <aegis/aenf.h>
+#include <aegis/aenfu.h>
+#include <aegis/aeni.h>
+#include <aegis/aenpa.h>
+#include <aegis/aenpr.h>
+#include <aegis/aenrls.h>
+#include <aegis/aenrv.h>
+#include <aegis/aent.h>
+#include <aegis/aentu.h>
+#include <aegis/aepa.h>
+#include <aegis/aer.h>
+#include <aegis/aera.h>
+#include <aegis/aerb.h>
+#include <aegis/aerbu.h>
+#include <aegis/aerd.h>
+#include <aegis/aerf.h>
+#include <aegis/aeri.h>
+#include <aegis/aerm.h>
+#include <aegis/aermpr.h>
+#include <aegis/aermu.h>
+#include <aegis/aerp.h>
+#include <aegis/aerpa.h>
+#include <aegis/aerpu.h>
+#include <aegis/aerrv.h>
+#include <aegis/aet.h>
+#include <libaegis/arglex2.h>
+#include <aegis/configured.h>
+#include <common/env.h>
+#include <libaegis/help.h>
+#include <common/language.h>
+#include <libaegis/log.h>
+#include <libaegis/os.h>
+#include <common/progname.h>
+#include <common/quit.h>
+#include <common/rsrc_limits.h>
+#include <common/trace.h>
+#include <libaegis/undo.h>
+#include <libaegis/version.h>
 
 
 static void
@@ -204,7 +203,6 @@ main(int argc, char **argv)
 #endif
 
     resource_limits_init();
-    r250_init();
     os_become_init();
     arglex2_init(argc, argv);
     env_initialize();
