@@ -1,6 +1,6 @@
 //
 //	aegis - project change supervisor
-//	Copyright (C) 2004 Peter Miller;
+//	Copyright (C) 2004, 2005 Peter Miller;
 //	All rights reserved.
 //
 //	This program is free software; you can redistribute it and/or modify
@@ -20,10 +20,8 @@
 // MANIFEST: implementation of the printer class
 //
 
-#pragma implementation "printer"
-
-#include <nstring/list.h>
-#include <printer.h>
+#include <common/nstring/list.h>
+#include <aemakefile/printer.h>
 
 
 printer::~printer()
