@@ -1,6 +1,6 @@
 //
 //	aegis - project change supervisor
-//	Copyright (C) 1995, 1996, 1998, 2004 Peter Miller;
+//	Copyright (C) 1995, 1996, 1998, 2004, 2005 Peter Miller;
 //	All rights reserved.
 //
 //	This program is free software; you can redistribute it and/or modify
@@ -20,7 +20,7 @@
 // MANIFEST: implement missing functions from <libintl.h>
 //
 
-#include <ac/libintl.h>
+#include <common/ac/libintl.h>
 
 
 //
