@@ -1,6 +1,6 @@
 //
 //	aegis - project change supervisor
-//	Copyright (C) 1999, 2002, 2004 Peter Miller;
+//	Copyright (C) 1999, 2002, 2004, 2005 Peter Miller;
 //	All rights reserved.
 //
 //	This program is free software; you can redistribute it and/or modify
@@ -20,7 +20,7 @@
 // MANIFEST: functions to implement mntent stubs
 //
 
-#include <ac/mntent.h>
+#include <common/ac/mntent.h>
 
 
 #ifndef HAVE_MNTENT_H
