@@ -1,6 +1,6 @@
 //
 //	aegis - project change supervisor
-//	Copyright (C) 2002, 2004 Peter Miller;
+//	Copyright (C) 2002, 2004, 2005 Peter Miller;
 //	All rights reserved.
 //
 //	This program is free software; you can redistribute it and/or modify
@@ -20,8 +20,8 @@
 // MANIFEST: functions to manipulate stdios
 //
 
-#include <ac/stdarg.h>
-#include <ac/stdio.h>
+#include <common/ac/stdarg.h>
+#include <common/ac/stdio.h>
 
 
 #ifndef HAVE_SNPRINTF
