@@ -1,6 +1,6 @@
 //
 //	aegis - project change supervisor
-//	Copyright (C) 1999, 2004 Peter Miller;
+//	Copyright (C) 1999, 2004, 2005 Peter Miller;
 //	All rights reserved.
 //
 //	This program is free software; you can redistribute it and/or modify
@@ -21,8 +21,8 @@
 //
 
 #include <errno.h>
-#include <ac/string.h>
-#include <ac/zlib.h>
+#include <common/ac/string.h>
+#include <common/ac/zlib.h>
 
 
 const char *
