@@ -1,6 +1,6 @@
 //
 //	aegis - project change supervisor
-//	Copyright (C) 2004 Peter Miller;
+//	Copyright (C) 2004, 2005 Peter Miller;
 //	All rights reserved.
 //
 //	This program is free software; you can redistribute it and/or modify
@@ -20,9 +20,7 @@
 // MANIFEST: implementation of the nstring class
 //
 
-#pragma implementation "nstring"
-
-#include <nstring.h>
+#include <common/nstring.h>
 
 
 nstring
