@@ -1,6 +1,6 @@
 //
 //	aegis - project change supervisor
-//	Copyright (C) 2004 Peter Miller;
+//	Copyright (C) 2004, 2005 Peter Miller;
 //	All rights reserved.
 //
 //	This program is free software; you can redistribute it and/or modify
@@ -20,9 +20,7 @@
 // MANIFEST: implementation of the quit_action class
 //
 
-#pragma implementation "quit_action"
-
-#include <quit/action.h>
+#include <common/quit/action.h>
 
 
 quit_action::~quit_action()
