@@ -1,6 +1,6 @@
 //
 //	aegis - project change supervisor
-//	Copyright (C) 2002, 2004 Peter Miller;
+//	Copyright (C) 2002, 2004, 2005 Peter Miller;
 //	All rights reserved.
 //
 //	This program is free software; you can redistribute it and/or modify
@@ -20,9 +20,9 @@
 // MANIFEST: functions to manipulate lead_prefixs
 //
 
-#include <ac/string.h>
+#include <common/ac/string.h>
 
-#include <str.h>
+#include <common/str.h>
 
 
 int
