@@ -1,6 +1,6 @@
 //
 //	aegis - project change supervisor
-//	Copyright (C) 2001, 2002, 2004 Peter Miller;
+//	Copyright (C) 2001, 2002, 2004, 2005 Peter Miller;
 //	All rights reserved.
 //
 //	This program is free software; you can redistribute it and/or modify
@@ -20,11 +20,11 @@
 // MANIFEST: functions to manipulate trims
 //
 
-#include <ac/ctype.h>
+#include <common/ac/ctype.h>
 
-#include <language.h>
-#include <str.h>
-#include <stracc.h>
+#include <common/language.h>
+#include <common/str.h>
+#include <common/stracc.h>
 
 
 string_ty *
