@@ -1,6 +1,6 @@
 //
 //	aegis - project change supervisor
-//	Copyright (C) 2004 Peter Miller;
+//	Copyright (C) 2004, 2005 Peter Miller;
 //	All rights reserved.
 //
 //	This program is free software; you can redistribute it and/or modify
@@ -20,9 +20,9 @@
 // MANIFEST: implementation of the str_list_member_nocas class
 //
 
-#include <ac/string.h>
+#include <common/ac/string.h>
 
-#include <str_list.h>
+#include <common/str_list.h>
 
 
 bool
