@@ -1,7 +1,7 @@
 #!/bin/sh
 #
 #	aegis - project change supervisor
-#	Copyright (C) 1992, 1993, 1995, 1999 Peter Miller;
+#	Copyright (C) 1992, 1993, 1995, 1999, 2001, 2002 Peter Miller;
 #	All rights reserved.
 #
 #	This program is free software; you can redistribute it and/or modify
@@ -21,7 +21,8 @@
 # MANIFEST: command used to notify by usenet that a change failed integration
 #
 # Suggested project attribute:
-# integrate_fail_notify_command = "$datadir/if.inews.sh $p $c a.local.newsgroup";
+# integrate_fail_notify_command =
+#	"$datadir/if.inews.sh $p $c a.local.newsgroup";
 #
 aegis=aegis
 case $# in
@@ -61,7 +62,8 @@ if [ $? -ne 0 ]; then quit; fi
 #
 # include full details of the change
 #
-$aegis -list change_details -project $project -change $change -verbose >> $tmp
+$aegis -list change_details -project $project -change $change -verbose \
+	-pl=66 -pw=80 >> $tmp
 if [ $? -ne 0 ]; then quit; fi
 
 #
