@@ -1,6 +1,6 @@
 //
 //	aegis - project change supervisor
-//	Copyright (C) 2004, 2005 Peter Miller;
+//	Copyright (C) 2004-2006 Peter Miller;
 //	All rights reserved.
 //
 //	This program is free software; you can redistribute it and/or modify
@@ -20,12 +20,12 @@
 // MANIFEST: implementation of the ael_change_inventory class
 //
 
-#include <ael/change/inventory.h>
-#include <change/functor/invento_list.h>
-#include <project.h>
-#include <project/invento_walk.h>
-#include <trace.h>
-#include <user.h>
+#include <libaegis/ael/change/inventory.h>
+#include <libaegis/change/functor/invento_list.h>
+#include <libaegis/project.h>
+#include <libaegis/project/invento_walk.h>
+#include <common/trace.h>
+#include <libaegis/user.h>
 
 
 void
@@ -42,7 +42,7 @@ list_change_inventory(string_ty *project_name, long change_number,
 	project_name = str_copy(project_name);
     project_ty *pp = project_alloc(project_name);
     str_free(project_name);
-    project_bind_existing(pp);
+    pp->bind_existing();
 
     //
     // create the columns
