@@ -1,6 +1,6 @@
 //
 //	aegis - project change supervisor
-//	Copyright (C) 1994-1996, 1999, 2001-2004 Peter Miller;
+//	Copyright (C) 1994-1996, 1999, 2001-2005 Peter Miller;
 //	All rights reserved.
 //
 //	This program is free software; you can redistribute it and/or modify
@@ -20,18 +20,18 @@
 // MANIFEST: functions to manipulate relative comparison expressions
 //
 
-#include <ac/string.h>
+#include <common/ac/string.h>
 
-#include <aer/expr/rel.h>
-#include <aer/value/boolean.h>
-#include <aer/value/error.h>
-#include <aer/value/integer.h>
-#include <aer/value/real.h>
-#include <aer/value/string.h>
-#include <error.h>
-#include <fstrcmp.h>
-#include <sub.h>
-#include <trace.h>
+#include <libaegis/aer/expr/rel.h>
+#include <libaegis/aer/value/boolean.h>
+#include <libaegis/aer/value/error.h>
+#include <libaegis/aer/value/integer.h>
+#include <libaegis/aer/value/real.h>
+#include <libaegis/aer/value/string.h>
+#include <common/error.h>
+#include <common/fstrcmp.h>
+#include <libaegis/sub.h>
+#include <common/trace.h>
 
 #define PAIR(a, b)	((a) * rpt_value_type_MAX + (b))
 
