@@ -1,6 +1,6 @@
 //
 //	aegis - project change supervisor
-//	Copyright (C) 1994, 2003, 2004 Peter Miller.
+//	Copyright (C) 1994, 2003-2005 Peter Miller.
 //	All rights reserved.
 //
 //	This program is free software; you can redistribute it and/or modify
@@ -20,11 +20,11 @@
 // MANIFEST: functions to impliment the builtin terse function
 //
 
-#include <aer/expr.h>
-#include <aer/func/terse.h>
-#include <aer/value/boolean.h>
-#include <error.h>
-#include <option.h>
+#include <libaegis/aer/expr.h>
+#include <libaegis/aer/func/terse.h>
+#include <libaegis/aer/value/boolean.h>
+#include <common/error.h>
+#include <libaegis/option.h>
 
 
 static int
