@@ -1,6 +1,6 @@
 //
 //	aegis - project change supervisor
-//	Copyright (C) 2004 Peter Miller;
+//	Copyright (C) 2004, 2005 Peter Miller;
 //	All rights reserved.
 //
 //	This program is free software; you can redistribute it and/or modify
@@ -20,9 +20,9 @@
 // MANIFEST: functions to manipulate version_paths
 //
 
-#include <change/file.h>
-#include <project/file.h>
-#include <trace.h>
+#include <libaegis/change/file.h>
+#include <libaegis/project/file.h>
+#include <common/trace.h>
 
 
 string_ty *
