@@ -23,9 +23,7 @@
 #ifndef LIBAEGIS_CHANGE_FUNCTOR_ATTRIBU_LIST_H
 #define LIBAEGIS_CHANGE_FUNCTOR_ATTRIBU_LIST_H
 
-#pragma interface "change_functor_attribute_list"
-
-#include <change/functor.h>
+#include <libaegis/change/functor.h>
 
 /**
   * The change_functor_attribute_list class is used to represent
