@@ -1,6 +1,6 @@
 //
 //	aegis - project change supervisor
-//	Copyright (C) 2004 Peter Miller;
+//	Copyright (C) 2004, 2005 Peter Miller;
 //	All rights reserved.
 //
 //	This program is free software; you can redistribute it and/or modify
@@ -20,9 +20,9 @@
 // MANIFEST: implementation of the change_identifi_sub_get_devdir class
 //
 
-#include <change.h>
-#include <change/identifi_sub.h>
-#include <cstate.h>
+#include <libaegis/change.h>
+#include <libaegis/change/identifi_sub.h>
+#include <libaegis/cstate.h>
 
 
 bool
