@@ -1,6 +1,6 @@
 //
 //	aegis - project change supervisor
-//	Copyright (C) 2004 Peter Miller;
+//	Copyright (C) 2004, 2005 Peter Miller;
 //	All rights reserved.
 //
 //	This program is free software; you can redistribute it and/or modify
@@ -20,7 +20,7 @@
 // MANIFEST: implementation of the change_id_set class
 //
 
-#include <change/identifi_sub.h>
+#include <libaegis/change/identifi_sub.h>
 
 
 bool
