@@ -1,6 +1,6 @@
 //
 //	aegis - project change supervisor
-//	Copyright (C) 2003, 2004 Peter Miller;
+//	Copyright (C) 2003-2005 Peter Miller;
 //	All rights reserved.
 //
 //	This program is free software; you can redistribute it and/or modify
@@ -20,9 +20,9 @@
 // MANIFEST: functions to manipulate is_completeds
 //
 
-#include <change.h>
-#include <cstate.h>
-#include <error.h>
+#include <common/error.h>
+#include <libaegis/change.h>
+#include <libaegis/cstate.h>
 
 
 int
