@@ -23,9 +23,7 @@
 #ifndef LIBAEGIS_CHANGE_LIST_H
 #define LIBAEGIS_CHANGE_LIST_H
 
-#pragma interface "change_list_ty"
-
-#include <main.h>
+#include <common/main.h>
 
 class change_list_ty
 {
