@@ -1,6 +1,6 @@
 //
 //	aegis - project change supervisor
-//	Copyright (C) 2004 Peter Miller;
+//	Copyright (C) 2004, 2005 Peter Miller;
 //	All rights reserved.
 //
 //	This program is free software; you can redistribute it and/or modify
@@ -20,8 +20,8 @@
 // MANIFEST: implementation of the change_reviewer_already class
 //
 
-#include <change.h>
-#include <str_list.h>
+#include <libaegis/change.h>
+#include <common/str_list.h>
 
 
 bool
