@@ -1,6 +1,6 @@
 //
 //	aegis - project change supervisor
-//	Copyright (C) 1999, 2002-2004 Peter Miller;
+//	Copyright (C) 1999, 2002-2005 Peter Miller;
 //	All rights reserved.
 //
 //	This program is free software; you can redistribute it and/or modify
@@ -20,9 +20,9 @@
 // MANIFEST: functions to manipulate projfileneeds
 //
 
-#include <change.h>
-#include <error.h>
-#include <project/history.h>
+#include <libaegis/change.h>
+#include <common/error.h>
+#include <libaegis/project/history.h>
 
 
 int
