@@ -1,6 +1,6 @@
 //
 //	aegis - project change supervisor
-//	Copyright (C) 2001, 2003, 2004 Peter Miller;
+//	Copyright (C) 2001, 2003-2005 Peter Miller;
 //	All rights reserved.
 //
 //	This program is free software; you can redistribute it and/or modify
@@ -20,12 +20,12 @@
 // MANIFEST: functions to manipulate file_fingerps
 //
 
-#include <ac/errno.h>
-#include <ac/string.h>
+#include <common/ac/errno.h>
+#include <common/ac/string.h>
 
-#include <fp/combined.h>
-#include <glue.h>
-#include <os.h>
+#include <common/fp/combined.h>
+#include <libaegis/glue.h>
+#include <libaegis/os.h>
 
 
 int
