@@ -1,29 +1,29 @@
-/*
- *	aegis - project change supervisor
- *	Copyright (C) 1991-1993, 1997, 2002-2004 Peter Miller;
- *	All rights reserved.
- *
- *	This program is free software; you can redistribute it and/or modify
- *	it under the terms of the GNU General Public License as published by
- *	the Free Software Foundation; either version 2 of the License, or
- *	(at your option) any later version.
- *
- *	This program is distributed in the hope that it will be useful,
- *	but WITHOUT ANY WARRANTY; without even the implied warranty of
- *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *	GNU General Public License for more details.
- *
- *	You should have received a copy of the GNU General Public License
- *	along with this program; if not, write to the Free Software
- *	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
- *
- * MANIFEST: interface definition for aegis/help.c
- */
+//
+//	aegis - project change supervisor
+//	Copyright (C) 1991-1993, 1997, 2002-2006 Peter Miller;
+//	All rights reserved.
+//
+//	This program is free software; you can redistribute it and/or modify
+//	it under the terms of the GNU General Public License as published by
+//	the Free Software Foundation; either version 2 of the License, or
+//	(at your option) any later version.
+//
+//	This program is distributed in the hope that it will be useful,
+//	but WITHOUT ANY WARRANTY; without even the implied warranty of
+//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+//	GNU General Public License for more details.
+//
+//	You should have received a copy of the GNU General Public License
+//	along with this program; if not, write to the Free Software
+//	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
+//
+// MANIFEST: interface definition for aegis/help.c
+//
 
 #ifndef HELP_H
 #define HELP_H
 
-#include <main.h>
+#include <common/main.h>
 
 void help(const char *progname, void (*usagefunc)(void));
 void generic_argument(void(*usagefunc)(void));
@@ -41,7 +41,7 @@ void option_needs_dir(int name, void(*usagefunc)(void));
 void option_needs_files(int name, void(*usagefunc)(void));
 void option_needs_uuid(int name, void(*usagefunc)(void));
 
-struct string_ty; /* forward */
+struct string_ty; // forward
 void fatal_too_many_files(void) NORETURN;
 void fatal_user_too_privileged(struct string_ty *) NORETURN;
 void fatal_group_too_privileged(struct string_ty *) NORETURN;
@@ -50,4 +50,4 @@ void fatal_project_name_too_long(struct string_ty *, int) NORETURN;
 void fatal_date_unknown(const char *) NORETURN;
 void fatal_project_alias_exists(struct string_ty *) NORETURN;
 
-#endif /* HELP_H */
+#endif // HELP_H
