@@ -1,6 +1,6 @@
 //
 //	aegis - project change supervisor
-//	Copyright (C) 1991-1996, 1999, 2002-2004 Peter Miller;
+//	Copyright (C) 1991-1996, 1999, 2002-2005 Peter Miller;
 //	All rights reserved.
 //
 //	This program is free software; you can redistribute it and/or modify
@@ -23,10 +23,10 @@
 #ifndef LIBAEGIS_IO_H
 #define LIBAEGIS_IO_H
 
-#include <ac/time.h>
+#include <common/ac/time.h>
 
-#include <main.h>
-#include <meta_type.h>
+#include <common/main.h>
+#include <libaegis/meta_type.h>
 
 struct sub_context_ty; // forward
 struct output_ty; // forward
