@@ -1,6 +1,6 @@
 //
 //	aegis - project change supervisor
-//	Copyright (C) 2002-2004 Peter Miller;
+//	Copyright (C) 2002-2005 Peter Miller;
 //	All rights reserved.
 //
 //	This program is free software; you can redistribute it and/or modify
@@ -20,12 +20,12 @@
 // MANIFEST: functions to manipulate readables
 //
 
-#include <ac/errno.h>
-#include <ac/fcntl.h>
-#include <ac/unistd.h>
+#include <common/ac/errno.h>
+#include <common/ac/fcntl.h>
+#include <common/ac/unistd.h>
 
-#include <os.h>
-#include <glue.h>
+#include <libaegis/os.h>
+#include <libaegis/glue.h>
 
 
 int
