@@ -1,6 +1,6 @@
 //
 //	aegis - project change supervisor
-//	Copyright (C) 2002-2004 Peter Miller;
+//	Copyright (C) 2002-2005 Peter Miller;
 //	All rights reserved.
 //
 //	This program is free software; you can redistribute it and/or modify
@@ -20,13 +20,13 @@
 // MANIFEST: functions to manipulate setuids
 //
 
-#include <ac/errno.h>
-#include <ac/stddef.h>
-#include <ac/sys/types.h>
-#include <ac/unistd.h>
+#include <common/ac/errno.h>
+#include <common/ac/stddef.h>
+#include <common/ac/sys/types.h>
+#include <common/ac/unistd.h>
 
-#include <os.h>
-#include <sub.h>
+#include <libaegis/os.h>
+#include <libaegis/sub.h>
 
 
 void
