@@ -1,6 +1,6 @@
 //
 //	aegis - project change supervisor
-//	Copyright (C) 2004 Peter Miller;
+//	Copyright (C) 2004, 2005 Peter Miller;
 //	All rights reserved.
 //
 //	This program is free software; you can redistribute it and/or modify
@@ -20,12 +20,12 @@
 // MANIFEST: wrappers around operating system functions
 //
 
-#include <ac/unistd.h>
+#include <common/ac/unistd.h>
 
-#include <file.h>
-#include <glue.h>
-#include <os.h>
-#include <trace.h>
+#include <libaegis/file.h>
+#include <libaegis/glue.h>
+#include <libaegis/os.h>
+#include <common/trace.h>
 
 
 void
