@@ -1,6 +1,6 @@
 //
 //	aegis - project change supervisor
-//	Copyright (C) 2001, 2002, 2004 Peter Miller;
+//	Copyright (C) 2001, 2002, 2004, 2005 Peter Miller;
 //	All rights reserved.
 //
 //	This program is free software; you can redistribute it and/or modify
@@ -23,7 +23,7 @@
 #ifndef LIBAEGIS_OUTPUT_CONTEN_ENCOD_H
 #define LIBAEGIS_OUTPUT_CONTEN_ENCOD_H
 
-#include <output.h>
+#include <libaegis/output.h>
 
 enum content_encoding_t
 {
