@@ -1,6 +1,6 @@
 //
 //	aegis - project change supervisor
-//	Copyright (C) 2001, 2003, 2004 Peter Miller;
+//	Copyright (C) 2001, 2003-2005 Peter Miller;
 //	All rights reserved.
 //
 //	This program is free software; you can redistribute it and/or modify
@@ -20,9 +20,7 @@
 // MANIFEST: functions to manipulate files
 //
 
-#pragma implementation "patch_ty"
-
-#include <patch.h>
+#include <libaegis/patch.h>
 
 
 patch_ty::patch_ty()
