@@ -1,6 +1,6 @@
 //
 //	aegis - project change supervisor
-//	Copyright (C) 2004 Peter Miller;
+//	Copyright (C) 2004-2006 Peter Miller;
 //	All rights reserved.
 //
 //	This program is free software; you can redistribute it and/or modify
@@ -20,8 +20,8 @@
 // MANIFEST: functions to manipulate briefdescgets
 //
 
-#include <change.h>
-#include <project.h>
+#include <libaegis/change.h>
+#include <libaegis/project.h>
 
 
 string_ty *
@@ -29,6 +29,6 @@ project_brief_description_get(project_ty *pp)
 {
     change_ty       *cp;
 
-    cp = project_change_get(pp);
+    cp = pp->change_get();
     return change_brief_description_get(cp);
 }
