@@ -1,6 +1,6 @@
 //
 //	aegis - project change supervisor
-//	Copyright (C) 1999, 2002, 2004 Peter Miller;
+//	Copyright (C) 1999, 2002, 2004-2006 Peter Miller;
 //	All rights reserved.
 //
 //	This program is free software; you can redistribute it and/or modify
@@ -20,9 +20,9 @@
 // MANIFEST: functions to manipulate removes
 //
 
-#include <change/file.h>
-#include <project/file.h>
-#include <trace.h>
+#include <libaegis/change/file.h>
+#include <libaegis/project/file.h>
+#include <common/trace.h>
 
 
 void
@@ -32,7 +32,7 @@ project_file_remove(project_ty *pp, string_ty *file_name)
 
     trace(("project_file_remove(pp = %8.8lX, file_name = \"%s\")\n{\n",
 	(long)pp, file_name->str_text));
-    cp = project_change_get(pp);
+    cp = pp->change_get();
     change_file_remove(cp, file_name);
     trace(("}\n"));
 }
