@@ -20,10 +20,10 @@
 // MANIFEST: functions to get a pattr from a project
 //
 
-#include <pattr.h>
-#include <project.h>
-#include <project/history.h>
-#include <project/pattr/get.h>
+#include <libaegis/pattr.h>
+#include <libaegis/project.h>
+#include <libaegis/project/history.h>
+#include <libaegis/project/pattr/get.h>
 
 
 void
