@@ -1,6 +1,6 @@
 //
 //	aegis - project change supervisor
-//	Copyright (C) 2001, 2002, 2004 Peter Miller;
+//	Copyright (C) 2001, 2002, 2004, 2005 Peter Miller;
 //	All rights reserved.
 //
 //	This program is free software; you can redistribute it and/or modify
@@ -20,9 +20,9 @@
 // MANIFEST: functions to manipulate newbrancomps
 //
 
-#include <project.h>
-#include <project/verbose.h>
-#include <sub.h>
+#include <libaegis/project.h>
+#include <libaegis/project/verbose.h>
+#include <libaegis/sub.h>
 
 
 void
