@@ -1,6 +1,6 @@
 //
 //	aegis - project change supervisor
-//	Copyright (C) 1995-1998, 2001-2004 Peter Miller;
+//	Copyright (C) 1995-1998, 2001-2006 Peter Miller;
 //	All rights reserved.
 //
 //	This program is free software; you can redistribute it and/or modify
@@ -20,12 +20,12 @@
 // MANIFEST: functions to manipulate project history
 //
 
-#include <change/branch.h>
-#include <error.h>
-#include <project/history.h>
-#include <trace.h>
-#include <str_list.h>
-#include <zero.h>
+#include <libaegis/change/branch.h>
+#include <common/error.h>
+#include <libaegis/project/history.h>
+#include <common/trace.h>
+#include <common/str_list.h>
+#include <libaegis/zero.h>
 
 
 bool
@@ -33,7 +33,7 @@ project_history_delta_validate(project_ty *pp, long delta_number)
 {
     change_ty       *cp;
 
-    cp = project_change_get(pp);
+    cp = pp->change_get();
     return change_history_delta_validate(cp, delta_number);
 }
 
@@ -57,7 +57,7 @@ project_history_delta_latest(project_ty *pp)
 {
     change_ty       *cp;
 
-    cp = project_change_get(pp);
+    cp = pp->change_get();
     return change_history_delta_latest(cp);
 }
 
@@ -67,7 +67,7 @@ project_history_delta_by_name(project_ty *pp, string_ty *delta_name, int errok)
 {
     change_ty       *cp;
 
-    cp = project_change_get(pp);
+    cp = pp->change_get();
     return change_history_delta_by_name(cp, delta_name, errok);
 }
 
@@ -77,7 +77,7 @@ project_history_change_by_name(project_ty *pp, string_ty *delta_name, int errok)
 {
     change_ty       *cp;
 
-    cp = project_change_get(pp);
+    cp = pp->change_get();
     return change_history_change_by_name(cp, delta_name, errok);
 }
 
@@ -94,7 +94,7 @@ project_history_change_by_delta(project_ty *pp, long delta_number)
 {
     change_ty       *cp;
 
-    cp = project_change_get(pp);
+    cp = pp->change_get();
     return change_history_change_by_delta(cp, delta_number);
 }
 
@@ -104,7 +104,7 @@ project_history_delta_name_delete(project_ty *pp, string_ty *delta_name)
 {
     change_ty       *cp;
 
-    cp = project_change_get(pp);
+    cp = pp->change_get();
     change_history_delta_name_delete(cp, delta_name);
 }
 
@@ -115,7 +115,7 @@ project_history_delta_name_add(project_ty *pp, long delta_number,
 {
     change_ty       *cp;
 
-    cp = project_change_get(pp);
+    cp = pp->change_get();
     change_history_delta_name_add(cp, delta_number, delta_name);
 }
 
@@ -128,7 +128,7 @@ project_current_integration_get(project_ty *pp)
 
     trace(("project_current_integration_get(pp = %8.8lX)\n{\n",
 	(long)pp));
-    cp = project_change_get(pp);
+    cp = pp->change_get();
     result = change_current_integration_get(cp);
     trace(("return %ld;\n", result));
     trace(("}\n"));
@@ -144,7 +144,7 @@ project_current_integration_set(project_ty *pp, long change_number)
     trace(("project_current_integration_set(pp = %8.8lX, n = %ld)\n{\n",
 	    (long)pp, change_number));
     assert(change_number >= 0 || change_number == MAGIC_ZERO);
-    cp = project_change_get(pp);
+    cp = pp->change_get();
     change_current_integration_set(cp, change_number);
     trace(("}\n"));
 }
@@ -155,7 +155,7 @@ project_next_delta_number(project_ty *pp)
 {
     change_ty       *cp;
 
-    cp = project_change_get(pp);
+    cp = pp->change_get();
     return change_branch_next_delta_number(cp);
 }
 
@@ -165,7 +165,7 @@ project_copyright_years_merge(project_ty *pp, change_ty *cp2)
 {
     change_ty       *cp1;
 
-    cp1 = project_change_get(pp);
+    cp1 = pp->change_get();
     change_copyright_years_merge(cp1, cp2);
 }
 
@@ -180,7 +180,7 @@ project_copyright_years_get(project_ty *pp, int *ary, int ary_len_max,
     // when we have the real thing, will need to get the years
     // from parent branches back to the trunk
     //
-    cp = project_change_get(pp);
+    cp = pp->change_get();
     change_copyright_years_get(cp, ary, ary_len_max, ary_len);
 }
 
@@ -190,7 +190,7 @@ project_copyright_year_append(project_ty *pp, int yyyy)
 {
     change_ty       *cp;
 
-    cp = project_change_get(pp);
+    cp = pp->change_get();
     change_copyright_year_append(cp, yyyy);
 }
 
@@ -202,7 +202,7 @@ project_history_new(project_ty *pp, long delta_number, long change_number)
 
     trace(("project_history_new(pp = %8.8lX, delta_number = %ld, "
 	"change_number = %ld)\n{\n", (long)pp, delta_number, change_number));
-    cp = project_change_get(pp);
+    cp = pp->change_get();
     change_branch_history_new(cp, delta_number, change_number);
     trace(("}\n"));
 }
@@ -217,7 +217,7 @@ project_history_nth(project_ty *pp, long n, long *cnp, long *dnp,
 
     trace(("project_history_nth(pp = %8.8lX, n = %ld)\n{\n",
 	(long)pp, n));
-    cp = project_change_get(pp);
+    cp = pp->change_get();
     result = change_branch_history_nth(cp, n, cnp, dnp, name);
     trace(("return %d;\n", result));
     trace(("}\n"));
@@ -230,7 +230,7 @@ project_administrator_query(project_ty *pp, string_ty *user_name)
 {
     trace(("project_administrator_query(pp = %8.8lX, user_name = \"%s\")\n{\n",
 	(long)pp, user_name->str_text));
-    change_ty *cp = project_change_get(pp);
+    change_ty *cp = pp->change_get();
     bool result = change_branch_administrator_query(cp, user_name);
     trace(("return %d;\n", result));
     trace(("}\n"));
@@ -245,7 +245,7 @@ project_administrator_add(project_ty *pp, string_ty *user_name)
 
     trace(("project_administrator_add(pp = %8.8lX, user_name = \"%s\")\n{\n",
 	(long)pp, user_name->str_text));
-    cp = project_change_get(pp);
+    cp = pp->change_get();
     change_branch_administrator_add(cp, user_name);
     trace(("}\n"));
 }
@@ -258,7 +258,7 @@ project_administrator_remove(project_ty *pp, string_ty *user_name)
 
     trace(("project_administrator_remove(pp = %8.8lX, user_name = \"%s\")\n{\n",
 	(long)pp, user_name->str_text));
-    cp = project_change_get(pp);
+    cp = pp->change_get();
     change_branch_administrator_remove(cp, user_name);
     trace(("}\n"));
 }
@@ -272,7 +272,7 @@ project_administrator_nth(project_ty *pp, long n)
 
     trace(("project_administrator_nth(pp = %8.8lX, n = %ld)\n{\n",
 	(long)pp, n));
-    cp = project_change_get(pp);
+    cp = pp->change_get();
     result = change_branch_administrator_nth(cp, n);
     trace(("return %8.8lX;\n", (long)result));
     trace(("}\n"));
@@ -285,7 +285,7 @@ project_developer_query(project_ty *pp, string_ty *user_name)
 {
     trace(("project_developer_query(pp = %8.8lX, user_name = \"%s\")\n{\n",
 	(long)pp, user_name->str_text));
-    change_ty *cp = project_change_get(pp);
+    change_ty *cp = pp->change_get();
     bool result = change_branch_developer_query(cp, user_name);
     trace(("return %d;\n", result));
     trace(("}\n"));
@@ -300,7 +300,7 @@ project_developer_add(project_ty *pp, string_ty *user_name)
 
     trace(("project_developer_add(pp = %8.8lX, user_name = \"%s\")\n{\n",
 	(long)pp, user_name->str_text));
-    cp = project_change_get(pp);
+    cp = pp->change_get();
     change_branch_developer_add(cp, user_name);
     trace(("}\n"));
 }
@@ -313,7 +313,7 @@ project_developer_remove(project_ty *pp, string_ty *user_name)
 
     trace(("project_developer_remove(pp = %8.8lX, user_name = \"%s\")\n{\n",
 	(long)pp, user_name->str_text));
-    cp = project_change_get(pp);
+    cp = pp->change_get();
     change_branch_developer_remove(cp, user_name);
     trace(("}\n"));
 }
@@ -327,7 +327,7 @@ project_developer_nth(project_ty *pp, long n)
 
     trace(("project_developer_nth(pp = %8.8lX, n = %ld)\n{\n",
 	(long)pp, n));
-    cp = project_change_get(pp);
+    cp = pp->change_get();
     result = change_branch_developer_nth(cp, n);
     trace(("return %8.8lX;\n", (long)result));
     trace(("}\n"));
@@ -340,7 +340,7 @@ project_reviewer_query(project_ty *pp, string_ty *user_name)
 {
     trace(("project_reviewer_query(pp = %8.8lX, user_name = \"%s\")\n{\n",
 	(long)pp, user_name->str_text));
-    change_ty *cp = project_change_get(pp);
+    change_ty *cp = pp->change_get();
     bool result = change_branch_reviewer_query(cp, user_name);
     trace(("return %d;\n", result));
     trace(("}\n"));
@@ -355,7 +355,7 @@ project_reviewer_add(project_ty *pp, string_ty *user_name)
 
     trace(("project_reviewer_add(pp = %8.8lX, user_name = \"%s\")\n{\n",
 	(long)pp, user_name->str_text));
-    cp = project_change_get(pp);
+    cp = pp->change_get();
     change_branch_reviewer_add(cp, user_name);
     trace(("}\n"));
 }
@@ -368,7 +368,7 @@ project_reviewer_remove(project_ty *pp, string_ty *user_name)
 
     trace(("project_reviewer_remove(pp = %8.8lX, user_name = \"%s\")\n{\n",
 	(long)pp, user_name->str_text));
-    cp = project_change_get(pp);
+    cp = pp->change_get();
     change_branch_reviewer_remove(cp, user_name);
     trace(("}\n"));
 }
@@ -382,7 +382,7 @@ project_reviewer_nth(project_ty *pp, long n)
 
     trace(("project_reviewer_nth(pp = %8.8lX, n = %ld)\n{\n",
 	(long)pp, n));
-    cp = project_change_get(pp);
+    cp = pp->change_get();
     result = change_branch_reviewer_nth(cp, n);
     trace(("return %8.8lX;\n", (long)result));
     trace(("}\n"));
@@ -395,7 +395,7 @@ project_integrator_query(project_ty *pp, string_ty *user_name)
 {
     trace(("project_integrator_query(pp = %8.8lX, user_name = \"%s\")\n{\n",
 	(long)pp, user_name->str_text));
-    change_ty *cp = project_change_get(pp);
+    change_ty *cp = pp->change_get();
     bool result = change_branch_integrator_query(cp, user_name);
     trace(("return %d;\n", result));
     trace(("}\n"));
@@ -410,7 +410,7 @@ project_integrator_add(project_ty *pp, string_ty *user_name)
 
     trace(("project_integrator_add(pp = %8.8lX, user_name = \"%s\")\n{\n",
 	(long)pp, user_name->str_text));
-    cp = project_change_get(pp);
+    cp = pp->change_get();
     change_branch_integrator_add(cp, user_name);
     trace(("}\n"));
 }
@@ -423,7 +423,7 @@ project_integrator_remove(project_ty *pp, string_ty *user_name)
 
     trace(("project_integrator_remove(pp = %8.8lX, user_name = \"%s\")\n{\n",
 	(long)pp, user_name->str_text));
-    cp = project_change_get(pp);
+    cp = pp->change_get();
     change_branch_integrator_remove(cp, user_name);
     trace(("}\n"));
 }
@@ -437,7 +437,7 @@ project_integrator_nth(project_ty *pp, long n)
 
     trace(("project_integrator_nth(pp = %8.8lX, n = %ld)\n{\n",
 	(long)pp, n));
-    cp = project_change_get(pp);
+    cp = pp->change_get();
     result = change_branch_integrator_nth(cp, n);
     trace(("return %8.8lX;\n", (long)result));
     trace(("}\n"));
@@ -452,7 +452,7 @@ project_change_add(project_ty *pp, long change_number, int is_a_branch)
 
     trace(("project_change_add(pp = %8.8lX, change_number = %ld)\n{\n",
 	(long)pp, change_number));
-    cp = project_change_get(pp);
+    cp = pp->change_get();
     change_branch_change_add(cp, change_number, is_a_branch);
     trace(("}\n"));
 }
@@ -465,7 +465,7 @@ project_change_remove(project_ty *pp, long change_number)
 
     trace(("project_change_remove(pp = %8.8lX, change_number = %ld)\n{\n",
 	(long)pp, change_number));
-    cp = project_change_get(pp);
+    cp = pp->change_get();
     change_branch_change_remove(cp, change_number);
     trace(("}\n"));
 }
@@ -478,7 +478,7 @@ project_change_nth(project_ty *pp, long n, long *cnp)
     int             result;
 
     trace(("project_change_nth(pp = %8.8lX, n = %ld)\n{\n", (long)pp, n));
-    cp = project_change_get(pp);
+    cp = pp->change_get();
     result = change_branch_change_nth(cp, n, cnp);
     trace(("return %d;\n", result));
     trace(("}\n"));
@@ -493,7 +493,7 @@ project_next_change_number(project_ty *pp, int skip)
     long            change_number;
 
     trace(("project_next_change_number(pp = %8.8lX)\n{\n", (long)pp));
-    cp = project_change_get(pp);
+    cp = pp->change_get();
     change_number = change_branch_next_change_number(cp, skip);
     trace(("return %ld;\n", change_number));
     trace(("}\n"));
@@ -515,9 +515,9 @@ project_last_change_integrated(project_ty *pp)
     n = 0;
     while (pp)
     {
-	cp = project_change_get(pp);
+	cp = pp->change_get();
 	n = n * 29 + change_history_last_change_integrated(cp);
-	pp = pp->parent;
+	pp = (pp->is_a_trunk() ? 0 : pp->parent_get());
     }
     return n;
 }
@@ -534,7 +534,7 @@ project_description_set(project_ty *pp, string_ty *s)
     //
     trace(("project_description_set(pp = %8.8lX, s = \"%s\")\n{\n",
 	(long)pp, s->str_text));
-    cp = project_change_get(pp);
+    cp = pp->change_get();
     cstate_data = change_cstate_get(cp);
     if (cstate_data->brief_description)
 	str_free(cstate_data->brief_description);
@@ -549,7 +549,7 @@ project_description_get(project_ty *pp)
     change_ty       *cp;
     cstate_ty       *cstate_data;
 
-    cp = project_change_get(pp);
+    cp = pp->change_get();
     cstate_data = change_cstate_get(cp);
     return cstate_data->brief_description;
 }
@@ -561,7 +561,7 @@ project_version_previous_get(project_ty *pp)
     change_ty       *cp;
     cstate_ty       *cstate_data;
 
-    cp = project_change_get(pp);
+    cp = pp->change_get();
     cstate_data = change_cstate_get(cp);
     return cstate_data->version_previous;
 }
@@ -573,7 +573,7 @@ project_version_previous_set(project_ty *pp, string_ty *s)
     change_ty       *cp;
     cstate_ty       *cstate_data;
 
-    cp = project_change_get(pp);
+    cp = pp->change_get();
     cstate_data = change_cstate_get(cp);
     if (cstate_data->version_previous)
 	str_free(cstate_data->version_previous);
@@ -587,63 +587,63 @@ project_version_previous_set(project_ty *pp, string_ty *s)
 void
 project_umask_set(project_ty *pp, int n)
 {
-    change_branch_umask_set(project_change_get(pp), n);
+    change_branch_umask_set(pp->change_get(), n);
 }
 
 
 int
 project_umask_get(project_ty *pp)
 {
-    return change_branch_umask_get(project_change_get(pp));
+    return change_branch_umask_get(pp->change_get());
 }
 
 
 void
 project_developer_may_review_set(project_ty *pp, bool n)
 {
-    change_branch_developer_may_review_set(project_change_get(pp), n);
+    change_branch_developer_may_review_set(pp->change_get(), n);
 }
 
 
 bool
 project_developer_may_review_get(project_ty *pp)
 {
-    return change_branch_developer_may_review_get(project_change_get(pp));
+    return change_branch_developer_may_review_get(pp->change_get());
 }
 
 
 void
 project_developer_may_integrate_set(project_ty *pp, bool n)
 {
-    change_branch_developer_may_integrate_set(project_change_get(pp), n);
+    change_branch_developer_may_integrate_set(pp->change_get(), n);
 }
 
 
 bool
 project_developer_may_integrate_get(project_ty *pp)
 {
-    return change_branch_developer_may_integrate_get(project_change_get(pp));
+    return change_branch_developer_may_integrate_get(pp->change_get());
 }
 
 
 void
 project_reviewer_may_integrate_set(project_ty *pp, bool n)
 {
-    change_branch_reviewer_may_integrate_set(project_change_get(pp), n);
+    change_branch_reviewer_may_integrate_set(pp->change_get(), n);
 }
 
 
 bool
 project_reviewer_may_integrate_get(project_ty *pp)
 {
-    return change_branch_reviewer_may_integrate_get(project_change_get(pp));
+    return change_branch_reviewer_may_integrate_get(pp->change_get());
 }
 
 
 void
 project_developers_may_create_changes_set(project_ty *pp, bool n)
 {
-    change_branch_developers_may_create_changes_set(project_change_get(pp), n);
+    change_branch_developers_may_create_changes_set(pp->change_get(), n);
 }
 
 
@@ -651,7 +651,7 @@ bool
 project_developers_may_create_changes_get(project_ty *pp)
 {
     return
-	change_branch_developers_may_create_changes_get(project_change_get(pp));
+	change_branch_developers_may_create_changes_get(pp->change_get());
 }
 
 
@@ -660,7 +660,7 @@ project_forced_develop_begin_notify_command_set(project_ty *pp, string_ty *s)
 {
     change_branch_forced_develop_begin_notify_command_set
     (
-	project_change_get(pp),
+	pp->change_get(),
 	s
     );
 }
@@ -672,7 +672,7 @@ project_forced_develop_begin_notify_command_get(project_ty *pp)
     return
 	change_branch_forced_develop_begin_notify_command_get
 	(
-	    project_change_get(pp)
+	    pp->change_get()
 	);
 }
 
@@ -680,14 +680,14 @@ project_forced_develop_begin_notify_command_get(project_ty *pp)
 void
 project_develop_end_notify_command_set(project_ty *pp, string_ty *s)
 {
-    change_branch_develop_end_notify_command_set(project_change_get(pp), s);
+    change_branch_develop_end_notify_command_set(pp->change_get(), s);
 }
 
 
 string_ty *
 project_develop_end_notify_command_get(project_ty *pp)
 {
-    return change_branch_develop_end_notify_command_get(project_change_get(pp));
+    return change_branch_develop_end_notify_command_get(pp->change_get());
 }
 
 
@@ -696,7 +696,7 @@ project_develop_end_undo_notify_command_set(project_ty *pp, string_ty *s)
 {
     change_branch_develop_end_undo_notify_command_set
     (
-	project_change_get(pp),
+	pp->change_get(),
 	s
     );
 }
@@ -708,7 +708,7 @@ project_develop_end_undo_notify_command_get(project_ty *pp)
     return
 	change_branch_develop_end_undo_notify_command_get
 	(
-	    project_change_get(pp)
+	    pp->change_get()
 	);
 }
 
@@ -716,14 +716,14 @@ project_develop_end_undo_notify_command_get(project_ty *pp)
 void
 project_review_pass_notify_command_set(project_ty *pp, string_ty *s)
 {
-    change_branch_review_pass_notify_command_set(project_change_get(pp), s);
+    change_branch_review_pass_notify_command_set(pp->change_get(), s);
 }
 
 
 string_ty *
 project_review_pass_notify_command_get(project_ty *pp)
 {
-    return change_branch_review_pass_notify_command_get(project_change_get(pp));
+    return change_branch_review_pass_notify_command_get(pp->change_get());
 }
 
 
@@ -732,7 +732,7 @@ project_review_pass_undo_notify_command_set(project_ty *pp, string_ty *s)
 {
     change_branch_review_pass_undo_notify_command_set
     (
-	project_change_get(pp),
+	pp->change_get(),
 	s
     );
 }
@@ -744,7 +744,7 @@ project_review_pass_undo_notify_command_get(project_ty *pp)
     return
 	change_branch_review_pass_undo_notify_command_get
 	(
-	    project_change_get(pp)
+	    pp->change_get()
 	);
 }
 
@@ -752,21 +752,21 @@ project_review_pass_undo_notify_command_get(project_ty *pp)
 void
 project_review_fail_notify_command_set(project_ty *pp, string_ty *s)
 {
-    change_branch_review_fail_notify_command_set(project_change_get(pp), s);
+    change_branch_review_fail_notify_command_set(pp->change_get(), s);
 }
 
 
 string_ty *
 project_review_fail_notify_command_get(project_ty *pp)
 {
-    return change_branch_review_fail_notify_command_get(project_change_get(pp));
+    return change_branch_review_fail_notify_command_get(pp->change_get());
 }
 
 
 void
 project_integrate_pass_notify_command_set(project_ty *pp, string_ty *s)
 {
-    change_branch_integrate_pass_notify_command_set(project_change_get(pp), s);
+    change_branch_integrate_pass_notify_command_set(pp->change_get(), s);
 }
 
 
@@ -774,14 +774,14 @@ string_ty *
 project_integrate_pass_notify_command_get(project_ty *pp)
 {
     return
-	change_branch_integrate_pass_notify_command_get(project_change_get(pp));
+	change_branch_integrate_pass_notify_command_get(pp->change_get());
 }
 
 
 void
 project_integrate_fail_notify_command_set(project_ty *pp, string_ty *s)
 {
-    change_branch_integrate_fail_notify_command_set(project_change_get(pp), s);
+    change_branch_integrate_fail_notify_command_set(pp->change_get(), s);
 }
 
 
@@ -789,33 +789,33 @@ string_ty *
 project_integrate_fail_notify_command_get(project_ty *pp)
 {
     return
-	change_branch_integrate_fail_notify_command_get(project_change_get(pp));
+	change_branch_integrate_fail_notify_command_get(pp->change_get());
 }
 
 
 void
 project_default_development_directory_set(project_ty *pp, string_ty *s)
 {
-    change_branch_default_development_directory_set(project_change_get(pp), s);
+    change_branch_default_development_directory_set(pp->change_get(), s);
 }
 
 string_ty *
 project_default_development_directory_get(project_ty *pp)
 {
     return
-	change_branch_default_development_directory_get(project_change_get(pp));
+	change_branch_default_development_directory_get(pp->change_get());
 }
 
 
 void
 project_default_test_exemption_set(project_ty *pp, bool n)
 {
-    change_branch_default_test_exemption_set(project_change_get(pp), n);
+    change_branch_default_test_exemption_set(pp->change_get(), n);
 }
 
 
 bool
 project_default_test_exemption_get(project_ty *pp)
 {
-    return change_branch_default_test_exemption_get(project_change_get(pp));
+    return change_branch_default_test_exemption_get(pp->change_get());
 }
