@@ -1,6 +1,7 @@
 #!/bin/sh
 #
 #	aegis - project change supervisor
+#	Copyright (C) 2006 Peter Miller
 #	Copyright (C) 2002 John Darrington
 #
 #	This program is free software; you can redistribute it and/or modify
@@ -51,6 +52,22 @@ if test $? -ne 0 ; then exit 2; fi
 
 bin=$here/${1-.}/bin
 
+if test "$EXEC_SEARCH_PATH" != ""
+then
+    tpath=
+    hold="$IFS"
+    IFS=":$IFS"
+    for tpath2 in $EXEC_SEARCH_PATH
+    do
+	tpath=${tpath}${tpath2}/${1-.}/bin:
+    done
+    IFS="$hold"
+    PATH=${tpath}${PATH}
+else
+    PATH=${bin}:${PATH}
+fi
+export PATH
+
 pass()
 {
 	set +x
@@ -196,20 +213,18 @@ if test $? -ne 0 ; then no_result; fi
 cat > $workchan/aegis.conf << 'end'
 build_command = "exit 0";
 link_integration_directory = true;
-history_get_command =
-	"co -u'$e' -p $h,v > $o";
-history_create_command =
-	"ci -f -u -m/dev/null -t/dev/null $i $h,v; rcs -U $h,v";
-history_put_command =
-	"ci -f -u -m/dev/null -t/dev/null $i $h,v; rcs -U $h,v";
-history_query_command =
-	"rlog -r $h,v | awk '/^head:/ {print $$2}'";
+
+history_get_command = "aesvt -check-out -edit ${quote $edit} "
+    "-history ${quote $history} -f ${quote $output}";
+history_put_command = "aesvt -check-in -history ${quote $history} "
+    "-f ${quote $input}";
+history_query_command = "aesvt -query -history ${quote $history}";
+history_content_limitation = binary_capable;
 
 history_label_command =
 /*	"rcs -n${SUBST \\\\. _ ${Label}}:${Edit} ${History}"; */
         "echo Labeling ${History} edit ${Edit} with t${SUBST \\\\. _ ${Label}}";
 
-
 diff_command = "set +e; diff $orig $i > $out; test $$? -le 1";
 diff3_command = "(diff3 -e $mr $orig $i | sed -e '/^w$$/d' -e '/^q$$/d'; \
 	echo '1,$$p' ) | ed - $mr > $out";
@@ -292,7 +307,7 @@ activity="integrate pass 291"
 $bin/aegis -intpass -nl  > log 2>&1
 if test $? -ne 0 ; then cat log; no_result; fi
 
-grep "Labeling .* edit 1.1 with t_D001" log > /dev/null
+grep "Labeling .* edit 1 with t_D001" log > /dev/null
 if test $? -ne 0 ; then cat log; fail; fi
 
 #
@@ -383,9 +398,9 @@ activity="integrate pass 382"
 $bin/aegis -intpass -nl  > log 2>&1
 if test $? -ne 0 ; then cat log; no_result; fi
 
-grep "Labeling .* edit 1.1 with t_D002" log > /dev/null
+grep "Labeling .* edit 1 with t_D002" log > /dev/null
 if test $? -ne 0 ; then cat log; fail; fi
-grep "Labeling .* edit 1.2 with t_D002" log > /dev/null
+grep "Labeling .* edit 2 with t_D002" log > /dev/null
 if test $? -ne 0 ; then cat log; fail; fi
 
 #
@@ -395,9 +410,9 @@ activity="label history head 394"
 $bin/aegis -delta_name XyZZY  > log 2>&1
 if test $? -ne 0 ; then cat log; no_result; fi
 
-grep "Labeling .* edit 1.1 with tXyZZY" log > /dev/null
+grep "Labeling .* edit 1 with tXyZZY" log > /dev/null
 if test $? -ne 0 ; then cat log; fail; fi
-grep "Labeling .* edit 1.2 with tXyZZY" log > /dev/null
+grep "Labeling .* edit 2 with tXyZZY" log > /dev/null
 if test $? -ne 0 ; then cat log; fail; fi
 
 #
@@ -407,7 +422,7 @@ activity="label history delta 1 406"
 $bin/aegis -delta_name 1 Foobar > log 2>&1
 if test $? -ne 0 ; then cat log; no_result; fi
 
-grep "Labeling .* edit 1.1 with tFoobar" log > /dev/null
+grep "Labeling .* edit 1 with tFoobar" log > /dev/null
 if test $? -ne 0 ; then cat log; fail; fi
 
 #
