@@ -1,7 +1,7 @@
 #!/bin/sh
 #
 #	aegis - project change supervisor
-#	Copyright (C) 2002, 2004, 2005 Peter Miller;
+#	Copyright (C) 2002, 2004-2006 Peter Miller;
 #	All rights reserved.
 #
 #	This program is free software; you can redistribute it and/or modify
@@ -38,11 +38,20 @@ if test $? -ne 0 ; then exit 2; fi
 
 if test "$1" != "" ; then bin="$here/$1/bin"; else bin="$here/bin"; fi
 
-#
-# set the path, so that the aegis command that aepath invokes
-# is from the same test set as the aepatch command itself.
-#
-PATH=${bin}:$PATH
+if test "$EXEC_SEARCH_PATH" != ""
+then
+    tpath=
+    hold="$IFS"
+    IFS=":$IFS"
+    for tpath2 in $EXEC_SEARCH_PATH
+    do
+	tpath=${tpath}${tpath2}/${1-.}/bin:
+    done
+    IFS="$hold"
+    PATH=${tpath}${PATH}
+else
+    PATH=${bin}:${PATH}
+fi
 export PATH
 
 check_it()
@@ -200,14 +209,14 @@ if test $? -ne 0 ; then no_result; fi
 cat > $workchan/aegis.conf << 'end'
 build_command = "exit 0";
 link_integration_directory = true;
-history_get_command =
-	"co -u'$e' -p $h,v > $o";
-history_create_command =
-	"ci -f -u -m/dev/null -t/dev/null $i $h,v; rcs -U $h,v";
-history_put_command =
-	"ci -f -u -m/dev/null -t/dev/null $i $h,v; rcs -U $h,v";
-history_query_command =
-	"rlog -r $h,v | awk '/^head:/ {print $$2}'";
+
+history_get_command = "aesvt -check-out -edit ${quote $edit} "
+    "-history ${quote $history} -f ${quote $output}";
+history_put_command = "aesvt -check-in -history ${quote $history} "
+    "-f ${quote $input}";
+history_query_command = "aesvt -query -history ${quote $history}";
+history_content_limitation = binary_capable;
+
 diff_command = "set +e; diff $orig $i > $out; test $$? -le 1";
 diff3_command = "(diff3 -e $mr $orig $i | sed -e '/^w$$/d' -e '/^q$$/d'; \
 	echo '1,$$p' ) | ed - $mr > $out";
@@ -411,7 +420,7 @@ src =
 		action = transparent;
 		edit_origin =
 		{
-			revision = "1.2";
+			revision = "2";
 			encoding = none;
 		};
 		usage = source;
@@ -445,15 +454,6 @@ state = being_developed;
 given_test_exemption = true;
 given_regression_test_exemption = true;
 project_file_command_sync = 88;
-build_time = TIME;
-architecture_times =
-[
-	{
-		variant = "unspecified";
-		node = "NODE";
-		build_time = TIME;
-	},
-];
 development_directory = ".../foo.chan";
 history =
 [
@@ -496,15 +496,6 @@ state = being_developed;
 given_test_exemption = true;
 given_regression_test_exemption = true;
 project_file_command_sync = 88;
-build_time = TIME;
-architecture_times =
-[
-	{
-		variant = "unspecified";
-		node = "NODE";
-		build_time = TIME;
-	},
-];
 development_directory = ".../foo.chan";
 history =
 [
@@ -534,7 +525,7 @@ src =
 		action = transparent;
 		edit_origin =
 		{
-			revision = "1.2";
+			revision = "2";
 			encoding = none;
 		};
 		usage = source;
@@ -574,7 +565,7 @@ src =
 		action = transparent;
 		edit_origin =
 		{
-			revision = "1.2";
+			revision = "2";
 			encoding = none;
 		};
 		usage = source;
@@ -613,15 +604,6 @@ state = being_reviewed;
 given_test_exemption = true;
 given_regression_test_exemption = true;
 project_file_command_sync = 88;
-build_time = TIME;
-architecture_times =
-[
-	{
-		variant = "unspecified";
-		node = "NODE";
-		build_time = TIME;
-	},
-];
 development_directory = ".../foo.chan";
 history =
 [
@@ -656,12 +638,12 @@ src =
 		action = modify;
 		edit =
 		{
-			revision = "1.2";
+			revision = "2";
 			encoding = none;
 		};
 		edit_origin =
 		{
-			revision = "1.1";
+			revision = "1";
 			encoding = none;
 		};
 		usage = source;
@@ -730,7 +712,7 @@ src =
 		action = transparent;
 		edit_origin =
 		{
-			revision = "1.2";
+			revision = "2";
 			encoding = none;
 		};
 		usage = source;
@@ -813,12 +795,12 @@ src =
 		action = transparent;
 		edit =
 		{
-			revision = "1.2";
+			revision = "2";
 			encoding = none;
 		};
 		edit_origin =
 		{
-			revision = "1.1";
+			revision = "1";
 			encoding = none;
 		};
 		usage = source;
@@ -853,12 +835,12 @@ src =
 		action = transparent;
 		edit =
 		{
-			revision = "1.2";
+			revision = "2";
 			encoding = none;
 		};
 		edit_origin =
 		{
-			revision = "1.1";
+			revision = "1";
 			encoding = none;
 		};
 		usage = source;
@@ -886,14 +868,8 @@ copyright_years =
 	YYYY,
 ];
 state = being_reviewed;
-build_time = TIME;
 architecture_times =
 [
-	{
-		variant = "unspecified";
-		node = "NODE";
-		build_time = TIME;
-	},
 ];
 development_directory = "branch.2";
 history =
@@ -980,12 +956,12 @@ src =
 		action = create;
 		edit =
 		{
-			revision = "1.1";
+			revision = "1";
 			encoding = none;
 		};
 		edit_origin =
 		{
-			revision = "1.1";
+			revision = "1";
 			encoding = none;
 		};
 		usage = config;
@@ -1002,12 +978,12 @@ src =
 		action = create;
 		edit =
 		{
-			revision = "1.1";
+			revision = "1";
 			encoding = none;
 		};
 		edit_origin =
 		{
-			revision = "1.1";
+			revision = "1";
 			encoding = none;
 		};
 		usage = source;
@@ -1062,12 +1038,12 @@ src =
 		action = transparent;
 		edit =
 		{
-			revision = "1.2";
+			revision = "2";
 			encoding = none;
 		};
 		edit_origin =
 		{
-			revision = "1.1";
+			revision = "1";
 			encoding = none;
 		};
 		usage = source;
@@ -1196,12 +1172,12 @@ src =
 		action = create;
 		edit =
 		{
-			revision = "1.1";
+			revision = "1";
 			encoding = none;
 		};
 		edit_origin =
 		{
-			revision = "1.1";
+			revision = "1";
 			encoding = none;
 		};
 		usage = config;
@@ -1218,12 +1194,12 @@ src =
 		action = create;
 		edit =
 		{
-			revision = "1.1";
+			revision = "1";
 			encoding = none;
 		};
 		edit_origin =
 		{
-			revision = "1.1";
+			revision = "1";
 			encoding = none;
 		};
 		usage = source;
