@@ -1,7 +1,7 @@
 #!/bin/sh
 #
 #	aegis - project change supervisor
-#	Copyright (C) 2004, 2005 Peter Miller;
+#	Copyright (C) 2004-2006 Peter Miller;
 #	All rights reserved.
 #
 #	This program is free software; you can redistribute it and/or modify
@@ -38,6 +38,22 @@ if test $? -ne 0 ; then exit 2; fi
 
 if test "$1" != "" ; then bin="$here/$1/bin"; else bin="$here/bin"; fi
 
+if test "$EXEC_SEARCH_PATH" != ""
+then
+    tpath=
+    hold="$IFS"
+    IFS=":$IFS"
+    for tpath2 in $EXEC_SEARCH_PATH
+    do
+	tpath=${tpath}${tpath2}/${1-.}/bin:
+    done
+    IFS="$hold"
+    PATH=${tpath}${PATH}
+else
+    PATH=${bin}:${PATH}
+fi
+export PATH
+
 no_result()
 {
 	set +x
@@ -203,14 +219,14 @@ if test $? -ne 0 ; then no_result; fi
 cat > $workchan/aegis.conf << 'end'
 build_command = "exit 0";
 link_integration_directory = true;
-history_get_command =
-	"co -u'$e' -p $h,v > $o";
-history_create_command =
-	"ci -f -u -m/dev/null -t/dev/null $i $h,v; rcs -U $h,v";
-history_put_command =
-	"ci -f -u -m/dev/null -t/dev/null $i $h,v; rcs -U $h,v";
-history_query_command =
-	"rlog -r $h,v | awk '/^head:/ {print $$2}'";
+
+history_get_command = "aesvt -check-out -edit ${quote $edit} "
+    "-history ${quote $history} -f ${quote $output}";
+history_put_command = "aesvt -check-in -history ${quote $history} "
+    "-f ${quote $input}";
+history_query_command = "aesvt -query -history ${quote $history}";
+history_content_limitation = binary_capable;
+
 diff_command = "set +e; diff $orig $i > $out; test $$? -le 1";
 diff3_command = "(diff3 -e $mr $orig $i | sed -e '/^w$$/d' -e '/^q$$/d'; \
 	echo '1,$$p' ) | ed - $mr > $out";
@@ -497,36 +513,32 @@ X
 #	X
 #X
 Index: main.cX
-*** main.cX
 --- main.cX
-***************X
-*** 1,8 ****X
---- 1,15 ----X
-+ #include <stdio.h>X
-+ X
-  intX
-  main(argc, argv)X
-  	int	argc;X
-  	char	**argv;X
-  {X
-+ 	if (argc != 1)X
-+ 	{X
-+ 		fprintf(stderr, "usage: %s\n", argv[0]);X
-+ 		exit(1);X
-+ 	}X
-  	test();X
-  	exit(0);X
-  	return 0;X
++++ main.cX
+@@ -1,8 +1,15 @@X
++#include <stdio.h>X
++X
+ intX
+ main(argc, argv)X
+ 	int	argc;X
+ 	char	**argv;X
+ {X
++	if (argc != 1)X
++	{X
++		fprintf(stderr, "usage: %s\n", argv[0]);X
++		exit(1);X
++	}X
+ 	test();X
+ 	exit(0);X
+ 	return 0;X
 Index: nothingmuchX
-*** nothingmuchX
 --- nothingmuchX
-***************X
-*** 1,4 ****X
-- these linesX
-- are the onesX
-- to beX
-- deletedX
---- 0 ----X
++++ nothingmuchX
+@@ -1,4 +0,0 @@X
+-these linesX
+-are the onesX
+-to beX
+-deletedX
 end
 if test $? -ne 0 ; then no_result; fi
 
