@@ -52,11 +52,20 @@ if test $? -ne 0 ; then exit 2; fi
 
 if test "$1" != "" ; then bin="$here/$1/bin"; else bin="$here/bin"; fi
 
-#
-# set the path, so that the aegis command that aepatch/aedist invokes
-# is from the same test set as the aepatch/aedist command itself.
-#
-PATH=${bin}:$PATH
+if test "$EXEC_SEARCH_PATH" != ""
+then
+    tpath=
+    hold="$IFS"
+    IFS=":$IFS"
+    for tpath2 in $EXEC_SEARCH_PATH
+    do
+	tpath=${tpath}${tpath2}/${1-.}/bin:
+    done
+    IFS="$hold"
+    PATH=${tpath}${PATH}
+else
+    PATH=${bin}:${PATH}
+fi
 export PATH
 
 pass()
@@ -211,14 +220,14 @@ if test $? -ne 0 ; then no_result; fi
 cat > $workchan/aegis.conf << 'end'
 build_command = "exit 0";
 link_integration_directory = true;
-history_get_command =
-	"co -u'$e' -p $h,v > $o";
-history_create_command =
-	"ci -f -u -m/dev/null -t/dev/null $i $h,v; rcs -U $h,v";
-history_put_command =
-	"ci -f -u -m/dev/null -t/dev/null $i $h,v; rcs -U $h,v";
-history_query_command =
-	"rlog -r $h,v | awk '/^head:/ {print $$2}'";
+
+history_get_command = "aesvt -check-out -edit ${quote $edit} "
+    "-history ${quote $history} -f ${quote $output}";
+history_put_command = "aesvt -check-in -history ${quote $history} "
+    "-f ${quote $input}";
+history_query_command = "aesvt -query -history ${quote $history}";
+history_content_limitation = binary_capable;
+
 diff_command = "set +e; diff $orig $i > $out; test $$? -le 1";
 merge_command = "(diff3 -e $i $orig $mr | sed -e '/^w$$/d' -e '/^q$$/d'; \
 	echo '1,$$p' ) | ed - $i > $out";
@@ -291,12 +300,12 @@ src =
 		action = create;
 		edit =
 		{
-			revision = "1.1";
+			revision = "1";
 			encoding = none;
 		};
 		edit_origin =
 		{
-			revision = "1.1";
+			revision = "1";
 			encoding = none;
 		};
 		usage = config;
@@ -313,12 +322,12 @@ src =
 		action = create;
 		edit =
 		{
-			revision = "1.1";
+			revision = "1";
 			encoding = none;
 		};
 		edit_origin =
 		{
-			revision = "1.1";
+			revision = "1";
 			encoding = none;
 		};
 		usage = source;
@@ -335,12 +344,12 @@ src =
 		action = create;
 		edit =
 		{
-			revision = "1.1";
+			revision = "1";
 			encoding = none;
 		};
 		edit_origin =
 		{
-			revision = "1.1";
+			revision = "1";
 			encoding = none;
 		};
 		usage = source;
@@ -398,7 +407,7 @@ src =
 		action = remove;
 		edit_origin =
 		{
-			revision = "1.1";
+			revision = "1";
 			encoding = none;
 		};
 		usage = source;
@@ -410,7 +419,7 @@ src =
 		action = create;
 		edit_origin =
 		{
-			revision = "1.1";
+			revision = "1";
 			encoding = none;
 		};
 		usage = source;
@@ -495,12 +504,12 @@ src =
 		action = create;
 		edit =
 		{
-			revision = "1.1";
+			revision = "1";
 			encoding = none;
 		};
 		edit_origin =
 		{
-			revision = "1.1";
+			revision = "1";
 			encoding = none;
 		};
 		usage = config;
@@ -517,12 +526,12 @@ src =
 		action = create;
 		edit =
 		{
-			revision = "1.1";
+			revision = "1";
 			encoding = none;
 		};
 		edit_origin =
 		{
-			revision = "1.1";
+			revision = "1";
 			encoding = none;
 		};
 		usage = source;
@@ -539,12 +548,12 @@ src =
 		action = create;
 		edit =
 		{
-			revision = "1.2";
+			revision = "2";
 			encoding = none;
 		};
 		edit_origin =
 		{
-			revision = "1.2";
+			revision = "2";
 			encoding = none;
 		};
 		usage = source;
@@ -587,7 +596,7 @@ src =
 		action = remove;
 		edit_origin =
 		{
-			revision = "1.2";
+			revision = "2";
 			encoding = none;
 		};
 		usage = source;
@@ -599,7 +608,7 @@ src =
 		action = create;
 		edit_origin =
 		{
-			revision = "1.2";
+			revision = "2";
 			encoding = none;
 		};
 		usage = source;
